summaryrefslogtreecommitdiff
path: root/ext/standard/array.c
diff options
context:
space:
mode:
authorDerick Rethans <derick@php.net>2001-11-11 18:28:43 +0000
committerDerick Rethans <derick@php.net>2001-11-11 18:28:43 +0000
commit78e4644fa1bdd4214709c3584b776d93a18615fd (patch)
tree1579fd648340db3040840b3eadb39da27d7b3538 /ext/standard/array.c
parent88c66d4859ba3ecc0b015259f78e905a5fe4df8c (diff)
downloadphp-git-78e4644fa1bdd4214709c3584b776d93a18615fd.tar.gz
- Renaming key_exists to array_key_exists
@- Renamed key_exists tp array_key_exists. (Derick) #- Not sure if this belongs in NEWS, but it was already in a released # version. And yes, I know I'm breaking BC here, but as it was not documented # yet, that doesn't matter.
Diffstat (limited to 'ext/standard/array.c')
-rw-r--r--ext/standard/array.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/ext/standard/array.c b/ext/standard/array.c
index 4e931c76e7..578f2dd7ac 100644
--- a/ext/standard/array.c
+++ b/ext/standard/array.c
@@ -3238,18 +3238,18 @@ PHP_FUNCTION(array_map)
/* }}} */
/* {{{ proto bool key_exists(mixed key, array search)
Checks if the given key or index exists in the array */
-PHP_FUNCTION(key_exists)
+PHP_FUNCTION(array_key_exists)
{
zval **key, /* key to check for */
**array; /* array to check in */
-
+
if (ZEND_NUM_ARGS() != 2 ||
zend_get_parameters_ex(ZEND_NUM_ARGS(), &key, &array) == FAILURE) {
WRONG_PARAM_COUNT;
}
-
+
if (Z_TYPE_PP(array) != IS_ARRAY && Z_TYPE_PP(array) != IS_OBJECT) {
php_error(E_WARNING, "Wrong datatype for second argument in call to %s", get_active_function_name(TSRMLS_C));
RETURN_FALSE;
@@ -3272,7 +3272,7 @@ PHP_FUNCTION(key_exists)
php_error(E_WARNING, "Wrong datatype for first argument in call to %s", get_active_function_name(TSRMLS_C));
RETURN_FALSE;
}
-
+
}
/* }}} */
@@ -3238,18 +3238,18 @@ PHP_FUNCTION(array_map)
/* }}} */
-/* {{{ proto bool key_exists(mixed key, array search)
+/* {{{ proto bool array_key_exists(mixed key, array search)
Checks if the given key or index exists in the array */